@@ -2,13 +2,10 @@
 
 use crate::{
     c_api::{self, nccell_load, NcChannels_u64, NCRESULT_ERR},
-    cstring, error, rstring, NcAlpha, NcCell, NcChannels, NcError, NcPaletteIndex, NcPlane,
-    NcResult, NcRgb, NcStyle,
+    cstring, error, rstring, NcAlpha, NcCell, NcChannel, NcChannels, NcError, NcPaletteIndex,
+    NcPlane, NcResult, NcRgb, NcStyle,
 };
 
-#[allow(unused_imports)] // for doc comments
-use crate::NcChannel;
-
 /// # NcCell constructors
 impl NcCell {
     /// New `NcCell`, expects a 7-bit [`char`].
@@ -33,7 +30,8 @@ impl NcCell {
     #[inline]
     pub fn from_char(plane: &mut NcPlane, ch: char) -> NcResult<Self> {
         let mut cell = Self::new();
-        let res = unsafe { nccell_load(plane, &mut cell, cstring![ch.to_string()]) };
+        let cs = cstring![ch.to_string()];
+        let res = unsafe { nccell_load(plane, &mut cell, cs.as_ptr()) };
         if res == NCRESULT_ERR {
             return Err(NcError::new());
         }
@@ -46,7 +44,8 @@ impl NcCell {
     #[inline]
     pub fn from_str(plane: &mut NcPlane, string: &str) -> NcResult<Self> {
         let mut cell = Self::new();
-        let res = unsafe { nccell_load(plane, &mut cell, cstring![string]) };
+        let cs = cstring![string];
+        let res = unsafe { nccell_load(plane, &mut cell, cs.as_ptr()) };
         if res == NCRESULT_ERR {
             return Err(NcError::new());
         }
@@ -65,7 +64,8 @@ impl NcCell {
     /// The styling of the cell is left untouched, but any resources are released.
     /// *C style function: [nccell_load()][c_api::nccell_load].*
     pub fn load(plane: &mut NcPlane, cell: &mut NcCell, egc: &str) -> NcResult<u32> {
-        let bytes = unsafe { c_api::nccell_load(plane, cell, cstring![egc]) };
+        let cs = cstring![egc];
+        let bytes = unsafe { c_api::nccell_load(plane, cell, cs.as_ptr()) };
         error![
             bytes,
             &format!["NcCell.load(NcPlane, NcCell, {:?})", egc],
@@ -86,10 +86,10 @@ impl NcCell {
         plane: &mut NcPlane,
         cell: &mut NcCell,
         gcluster: &str,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
     ) -> NcResult<u32> {
-        let bytes = c_api::nccell_prime(plane, cell, gcluster, style.into(), channels.into());
+        let bytes = c_api::nccell_prime(plane, cell, gcluster, style.into().0, channels.into().0);
         error![bytes, "", bytes as u32]
     }
 
@@ -125,20 +125,58 @@ impl NcCell {
 // -----------------------------------------------------------------------------
 /// ## NcCell methods: bg|fg `NcChannel`s manipulation.
 impl NcCell {
-    /// Returns the [`NcChannels`] of this `NcCell`.
+    /// Gets the background alpha and coloring bits from the cell [`NcChannels`]
+    /// as an [`NcChannel`].
     ///
-    /// *(No equivalent C style function)*
-    pub fn channels(&mut self, plane: &mut NcPlane) -> NcChannels {
-        let (mut styles, mut channels) = (0, 0);
-        let _egc = c_api::nccell_extract(plane, self, &mut styles, &mut channels);
-        channels.into()
+    /// *C style function: [nccell_bchannel()][c_api::nccell_bchannel].*
+    pub fn bchannel(&self) -> NcChannel {
+        c_api::nccell_bchannel(self).into()
     }
 
-    /// Extracts the background [`NcAlpha`] (shifted to LSBs).
+    /// Gets the foreground alpha and coloring bits from the cell [`NcChannels`]
+    /// as an [`NcChannel`].
+    ///
+    /// *C style function: [nccell_fchannel()][c_api::nccell_fchannel].*
+    pub fn fchannel(&self) -> NcChannel {
+        c_api::nccell_fchannel(self).into()
+    }
+
+    /// Gets the alpha and coloring bits from the cell [`NcChannels`].
+    ///
+    /// *C style function: [nccell_channels()][c_api::nccell_channels].*
+    pub fn channels(&self) -> NcChannels {
+        c_api::nccell_channels(self).into()
+    }
+
+    /// Sets the background alpha and coloring bits of the cell [`NcChannels`],
+    /// returning the new [`NcChannels_u64`].
+    ///
+    /// *C style function: [nccell_bchannel()][c_api::nccell_bchannel].*
+    pub fn set_bchannel(&mut self, from: impl Into<NcChannel>) -> NcChannels {
+        c_api::nccell_set_bchannel(self, from.into().0).into()
+    }
+
+    /// Sets the foreground alpha and coloring bits from the cell [`NcChannels`],
+    /// returning the new [`NcChannels_u64`].
+    ///
+    /// *C style function: [nccell_set_fchannel()][c_api::nccell_set_fchannel].*
+    pub fn set_fchannel(&mut self, from: impl Into<NcChannel>) -> NcChannels {
+        c_api::nccell_set_fchannel(self, from.into().0).into()
+    }
+
+    /// Sets the alpha and coloring bits of the cell [`NcChannels`]
+    /// from another [`NcChannels`], returning the new [`NcChannels`].
+    ///
+    /// *C style function: [nccell_set_channels()][c_api::nccell_set_channels].*
+    pub fn set_channels(&mut self, from: impl Into<NcChannels>) -> NcChannels {
+        c_api::nccell_set_channels(self, from.into().0).into()
+    }
+
+    /// Gets the background [`NcAlpha`] (shifted to LSBs).
     ///
     /// *C style function: [nccell_bg_alpha()][c_api::nccell_bg_alpha].*
     pub fn bg_alpha(&self) -> NcAlpha {
-        c_api::nccell_bg_alpha(self)
+        c_api::nccell_bg_alpha(self).into()
     }
 
     /// Is the background [`NcChannel`] using the "default background color"?
@@ -170,20 +208,11 @@ impl NcCell {
         c_api::nccell_bg_rgb(self).into()
     }
 
-    /// Gets the background RGB components.
-    ///
-    /// *C style function: [nccell_bg_rgb8()][c_api::nccell_bg_rgb8].*
-    pub fn bg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        c_api::nccell_bg_rgb8(self, &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
-    /// Extracts the foreground [`NcAlpha`] (shifted to LSBs).
+    /// Gets the foreground [`NcAlpha`] (shifted to LSBs).
     ///
     /// *C style function: [nccell_fg_alpha()][c_api::nccell_fg_alpha].*
     pub fn fg_alpha(&self) -> NcAlpha {
-        c_api::nccell_fg_alpha(self)
+        c_api::nccell_fg_alpha(self).into()
     }
 
     /// Is the foreground [`NcChannel`] using the "default foreground color"?
@@ -215,20 +244,11 @@ impl NcCell {
         c_api::nccell_fg_rgb(self).into()
     }
 
-    /// Gets the foreground RGB components.
-    ///
-    /// *C style function: [nccell_fg_rgb8()][c_api::nccell_fg_rgb8].*
-    pub fn fg_rgb8(&self) -> (u8, u8, u8) {
-        let (mut r, mut g, mut b) = (0, 0, 0);
-        c_api::nccell_fg_rgb8(self, &mut r, &mut g, &mut b);
-        (r, g, b)
-    }
-
     /// Sets the background [`NcAlpha`].
     ///
     /// *C style function: [nccell_set_bg_alpha()][c_api::nccell_set_bg_alpha].*
-    pub fn set_bg_alpha(&mut self, alpha: NcAlpha) {
-        c_api::nccell_set_bg_alpha(self, alpha);
+    pub fn set_bg_alpha(&mut self, alpha: impl Into<NcAlpha>) {
+        c_api::nccell_set_bg_alpha(self, alpha.into());
     }
 
     /// Indicates to use the "default color" for the background [`NcChannel`].
@@ -247,30 +267,22 @@ impl NcCell {
     /// [`NcChannels::BG_DEFAULT_MASK`][NcChannels#associatedconstant.BG_DEFAULT_MASK].
     ///
     /// *C style function: [nccell_set_bg_palindex()][c_api::nccell_set_bg_palindex].*
-    pub fn set_bg_palindex(&mut self, index: NcPaletteIndex) {
-        c_api::nccell_set_bg_palindex(self, index);
+    pub fn set_bg_palindex(&mut self, index: impl Into<NcPaletteIndex>) {
+        c_api::nccell_set_bg_palindex(self, index.into());
     }
 
     /// Sets the background [`NcRgb`] and marks it as not using the default color.
     ///
     /// *C style function: [nccell_set_bg_rgb()][c_api::nccell_set_bg_rgb].*
-    pub fn set_bg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
-        c_api::nccell_set_bg_rgb(self, rgb.into().into());
-    }
-
-    /// Sets the background RGB components, and marks it as not using
-    /// the "default color".
-    ///
-    /// *C style function: [nccell_set_bg_rgb8()][c_api::nccell_set_bg_rgb8].*
-    pub fn set_bg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
-        c_api::nccell_set_bg_rgb8(self, red, green, blue);
+    pub fn set_bg_rgb(&mut self, rgb: impl Into<NcRgb>) {
+        c_api::nccell_set_bg_rgb(self, rgb.into().0);
     }
 
     /// Sets the foreground [`NcAlpha`].
     ///
     /// *C style function: [nccell_set_fg_alpha()][c_api::nccell_set_fg_alpha].*
-    pub fn set_fg_alpha(&mut self, alpha: NcAlpha) {
-        c_api::nccell_set_fg_alpha(self, alpha);
+    pub fn set_fg_alpha(&mut self, alpha: impl Into<NcAlpha>) {
+        c_api::nccell_set_fg_alpha(self, alpha.into());
     }
 
     /// Indicates to use the "default color" for the foreground [`NcChannel`].
@@ -289,23 +301,15 @@ impl NcCell {
     /// [`NcChannels::FG_DEFAULT_MASK`][NcChannels#associatedconstant.FG_DEFAULT_MASK].
     ///
     /// *C style function: [nccell_set_fg_palindex()][c_api::nccell_set_fg_palindex].*
-    pub fn set_fg_palindex(&mut self, index: NcPaletteIndex) {
-        c_api::nccell_set_fg_palindex(self, index);
+    pub fn set_fg_palindex(&mut self, index: impl Into<NcPaletteIndex>) {
+        c_api::nccell_set_fg_palindex(self, index.into());
     }
 
     /// Sets the foreground [`NcRgb`] and marks it as not using the default color.
     ///
     /// *C style function: [nccell_set_fg_rgb()][c_api::nccell_set_fg_rgb].*
-    pub fn set_fg_rgb<RGB: Into<NcRgb>>(&mut self, rgb: RGB) {
-        c_api::nccell_set_fg_rgb(self, rgb.into().into());
-    }
-
-    /// Sets the foreground RGB components, and marks it as not using
-    /// the "default color".
-    ///
-    /// *C style function: [nccell_set_fg_rgb8()][c_api::nccell_set_fg_rgb8].*
-    pub fn set_fg_rgb8(&mut self, red: u8, green: u8, blue: u8) {
-        c_api::nccell_set_fg_rgb8(self, red, green, blue);
+    pub fn set_fg_rgb(&mut self, rgb: impl Into<NcRgb>) {
+        c_api::nccell_set_fg_rgb(self, rgb.into().0);
     }
 }
 
@@ -355,22 +359,22 @@ impl NcCell {
     /// Removes the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_off_styles()][c_api::nccell_off_styles].*
-    pub fn styles_off(&mut self, stylebits: NcStyle) {
-        c_api::nccell_off_styles(self, stylebits.into())
+    pub fn styles_off(&mut self, stylebits: impl Into<NcStyle>) {
+        c_api::nccell_off_styles(self, stylebits.into().0)
     }
 
     /// Adds the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_on_styles()][c_api::nccell_on_styles].*
-    pub fn styles_on(&mut self, stylebits: NcStyle) {
-        c_api::nccell_on_styles(self, stylebits.into())
+    pub fn styles_on(&mut self, stylebits: impl Into<NcStyle>) {
+        c_api::nccell_on_styles(self, stylebits.into().0)
     }
 
     /// Sets just the specified [`NcStyle`] bits.
     ///
     /// *C style function: [nccell_set_styles()][c_api::nccell_set_styles].*
-    pub fn styles_set(&mut self, stylebits: NcStyle) {
-        c_api::nccell_set_styles(self, stylebits.into())
+    pub fn styles_set(&mut self, stylebits: impl Into<NcStyle>) {
+        c_api::nccell_set_styles(self, stylebits.into().0)
     }
 }
 
@@ -442,8 +446,8 @@ impl NcCell {
     /// *C style function: [nccells_load_box()][c_api::nccells_load_box].*
     pub fn load_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle> + Copy,
+        channels: impl Into<NcChannels> + Copy,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -471,8 +475,8 @@ impl NcCell {
     /// *C style function: [nccells_double_box()][c_api::nccells_double_box].*
     pub fn double_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -482,8 +486,8 @@ impl NcCell {
     ) -> NcResult<()> {
         error![c_api::nccells_double_box(
             plane,
-            style.into(),
-            channels.into(),
+            style.into().0,
+            channels.into().0,
             ul,
             ur,
             ll,
@@ -498,8 +502,8 @@ impl NcCell {
     /// *C style function: [nccells_rounded_box()][c_api::nccells_double_box].*
     pub fn rounded_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -509,8 +513,8 @@ impl NcCell {
     ) -> NcResult<()> {
         error![c_api::nccells_rounded_box(
             plane,
-            style.into(),
-            channels.into(),
+            style.into().0,
+            channels.into().0,
             ul,
             ur,
             ll,
@@ -525,8 +529,8 @@ impl NcCell {
     /// *C style function: [nccells_ascii_box()][c_api::nccells_ascii_box].*
     pub fn ascii_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -536,8 +540,8 @@ impl NcCell {
     ) -> NcResult<()> {
         error![c_api::nccells_ascii_box(
             plane,
-            style.into(),
-            channels.into(),
+            style.into().0,
+            channels.into().0,
             ul,
             ur,
             ll,
@@ -552,8 +556,8 @@ impl NcCell {
     /// *C style function: [nccells_heavy_box()][c_api::nccells_heavy_box].*
     pub fn heavy_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -563,8 +567,8 @@ impl NcCell {
     ) -> NcResult<()> {
         error![c_api::nccells_heavy_box(
             plane,
-            style.into(),
-            channels.into(),
+            style.into().0,
+            channels.into().0,
             ul,
             ur,
             ll,
@@ -580,8 +584,8 @@ impl NcCell {
     /// *C style function: [nccells_light_box()][c_api::nccells_light_box].*
     pub fn light_box(
         plane: &mut NcPlane,
-        style: NcStyle,
-        channels: NcChannels,
+        style: impl Into<NcStyle>,
+        channels: impl Into<NcChannels>,
         ul: &mut NcCell,
         ur: &mut NcCell,
         ll: &mut NcCell,
@@ -591,8 +595,8 @@ impl NcCell {
     ) -> NcResult<()> {
         error![c_api::nccells_light_box(
             plane,
-            style.into(),
-            channels.into(),
+            style.into().0,
+            channels.into().0,
             ul,
             ur,
             ll,
