@@ -5,8 +5,8 @@ use core::ptr::{null, null_mut};
 use crate::{
     c_api::{self, notcurses_init},
     cstring, error, error_ref_mut, rstring, rstring_free, Nc, NcAlign, NcBlitter, NcCapabilities,
-    NcChannels, NcError, NcFile, NcFlag, NcInput, NcLogLevel, NcMiceEvents, NcOptions, NcPixelImpl,
-    NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle, NcTime, NcVisual,
+    NcChannels, NcError, NcFd, NcFile, NcFlag, NcInput, NcLogLevel, NcMiceEvents, NcOptions,
+    NcPixelImpl, NcPlane, NcReceived, NcResult, NcRgb, NcScale, NcStats, NcStyle, NcTime, NcVisual,
     NcVisualGeometry, NcVisualOptions,
 };
 
@@ -71,61 +71,56 @@ impl NcOptions {
 }
 
 /// # `Nc` Constructors and destructors
-//
-// TODO: rethink constructors
 impl Nc {
-    /// New notcurses context (without banners).
+    /// New notcurses context.
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
     pub unsafe fn new<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlag::SuppressBanners)
+        Self::with_flags(NcFlag::None)
     }
 
     /// New notcurses context in CLI mode.
     ///
-    /// It has the following flags:
-    /// - [`NcFlag::SuppressBanners`][NcFlag#associatedconstant.SuppressBanners]
-    /// - [`NcFlag::NoAlternateScreen`][NcFlag#associatedconstant.NoAlternateScreen]
-    /// - [`NcFlag::NoClearBitmaps`][NcFlag#associatedconstant.NoClearBitmaps]
-    /// - [`NcFlag::PreserveCursor`][NcFlag#associatedconstant.PreserveCursor]
+    /// Has the [`CliMode`] flag enabled.
+    ///
+    /// [`CliMode`]: NcFlag#associatedconstant.CliMode
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
     pub unsafe fn new_cli<'a>() -> NcResult<&'a mut Nc> {
         Self::with_flags(NcFlag::CliMode)
     }
 
-    /// New notcurses context, with banners.
+    /// New notcurses context, without banners.
     ///
-    /// This is the default in the C library.
+    /// It has the [`SuppressBanners`] flag enabled.
+    ///
+    /// [`SuppressBanners`]: NcFlag#associatedconstant.SuppressBanners
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
-    pub unsafe fn with_banners<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlag::None)
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
+    pub unsafe fn new_silent<'a>() -> NcResult<&'a mut Nc> {
+        Self::with_flags(NcFlag::SuppressBanners)
     }
 
-    /// New notcurses context, without an alternate screen (nor banners).
+    /// New notcurses context in CLI mode, without banners.
     ///
-    #[deprecated]
-    #[doc(hidden)]
-    pub unsafe fn without_altscreen<'a>() -> NcResult<&'a mut Nc> {
-        Self::with_flags(NcFlag::NoAlternateScreen | NcFlag::SuppressBanners)
+    /// It has the [`CliMode`] and [`SuppressBanners`] flags enabled.
+    ///
+    /// [`CliMode`]: NcFlag#associatedconstant.CliMode
+    /// [`SuppressBanners`]: NcFlag#associatedconstant.SuppressBanners
+    ///
+    /// # Safety
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
+    pub unsafe fn new_cli_silent<'a>() -> NcResult<&'a mut Nc> {
+        Self::with_flags(NcFlag::CliMode | NcFlag::SuppressBanners)
     }
 
     /// New notcurses context, expects [`NcFlag`].
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
     pub unsafe fn with_flags<'a>(flags: impl Into<NcFlag>) -> NcResult<&'a mut Nc> {
         Self::with_options(NcOptions::with_flags(flags.into()))
     }
@@ -133,20 +128,16 @@ impl Nc {
     /// New notcurses context, expects [NcOptions].
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
     pub unsafe fn with_options<'a>(options: NcOptions) -> NcResult<&'a mut Nc> {
         let res = notcurses_init(&options, null_mut());
-        error_ref_mut![res, "Nc.with_options()"]
+        error_ref_mut![res, &format!["Nc.with_options({:?})", options]]
     }
 
     /// New notcurses context, expects [NcLogLevel] and flags.
     ///
     /// # Safety
-    /// You must not create multiple `Nc` instances at the same time, on
-    /// the same thread. You must [`stop`][Nc#method.stop] the current one
-    /// before creating a new one.
+    /// You can't have multiple simultaneous `Nc` instances in the same thread.
     pub unsafe fn with_debug<'a>(
         loglevel: impl Into<NcLogLevel>,
         flags: impl Into<NcFlag>,
@@ -524,8 +515,9 @@ impl Nc {
     /// with stdin (but it might be!).
     ///
     /// *C style function: [notcurses_inputready_fd()][c_api::notcurses_inputready_fd].*
-    pub fn inputready_fd(&mut self) -> NcResult<()> {
-        error![unsafe { c_api::notcurses_inputready_fd(self) }]
+    pub fn inputready_fd(&mut self) -> NcResult<NcFd> {
+        let res = unsafe { c_api::notcurses_inputready_fd(self) };
+        error![res, "", res]
     }
 
     /// Returns an [`NcBlitter`] from a string representation.
