@@ -37,9 +37,11 @@ impl NcMenu {
     ///
     /// *C style function: [ncmenu_item_set_status()][c_api::ncmenu_item_set_status].*
     pub fn item_set_status(&mut self, section: &str, item: &str, enabled: bool) -> NcResult<()> {
+        let csection = cstring![section];
+        let citem = cstring![item];
         error![
             unsafe {
-                c_api::ncmenu_item_set_status(self, cstring![section], cstring![item], enabled)
+                c_api::ncmenu_item_set_status(self, csection.as_ptr(), citem.as_ptr(), enabled)
             },
             &format!(
                 ".item_set_status({:?}, {:?}, {:?}, {})",
@@ -63,12 +65,7 @@ impl NcMenu {
         click: NcInput,
         shortcut: Option<&mut NcInput>,
     ) -> NcResult<String> {
-        let ninput;
-        if let Some(i) = shortcut {
-            ninput = i as *mut _;
-        } else {
-            ninput = null_mut();
-        }
+        let ninput = if let Some(i) = shortcut { i as *mut _ } else { null_mut() };
         error_str![
             unsafe { c_api::ncmenu_mouse_selected(self, &click, ninput) },
             "Getting NcMenuItem description"
@@ -155,12 +152,7 @@ impl NcMenu {
     ///
     /// *C style function: [ncmenu_selected()][c_api::ncmenu_selected].*
     pub fn selected(&mut self, shortcut: Option<&mut NcInput>) -> Option<String> {
-        let ninput;
-        if let Some(i) = shortcut {
-            ninput = i as *mut _;
-        } else {
-            ninput = null_mut();
-        }
+        let ninput = if let Some(i) = shortcut { i as *mut _ } else { null_mut() };
         let res = unsafe { c_api::ncmenu_selected(self, ninput) };
         if !res.is_null() {
             Some(rstring![&*res].to_string())
